==> Tridium_EMEA_N4_Supervisor-4.10.11.12.zip: rc/ux/Picture.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
/**
 * Copyright 2020 Tridium, Inc. All Rights Reserved.
 */

/* eslint-env browser */

/**
 * API Status: **Private**
 * @module nmodule/bajaui/rc/ux/Picture
 */
define(['baja!', 'bajaux/spandrel', 'bajaux/icon/iconUtils', 'jquery', 'nmodule/webEditors/rc/fe/baja/IconEditor', 'nmodule/webEditors/rc/fe/fe', 'nmodule/bajaui/rc/util/ScaledLayout', 'baja!bajaui:Halign,bajaui:ScaleMode,bajaui:Valign,gx:Image'], function (baja, spandrel, iconUtils, $, IconEditor, fe, ScaledLayout) {
  'use strict';

  var widgetDefaults = function widgetDefaults() {
    return {
      properties: {
        rootCssClass: 'ux-Picture',
        halign: baja.$('bajaui:Halign', 'center'),
        valign: baja.$('bajaui:Valign', 'center'),
        image: baja.$('gx:Image', 'null'),
        scale: baja.$('bajaui:ScaleMode', 'none')
      }
    };
  };

  /**
   * @class
   * @alias module:nmodule/bajaui/rc/ux/Picture
   * @extends {module:bajaux/Widget}
   */
  return /*#__PURE__*/function (_spandrel) {
    function Picture(params) {
      _classCallCheck(this, Picture);
      return _callSuper(this, Picture, [{
        params: params,
        defaults: widgetDefaults()
      }]);
    }
    _inherits(Picture, _spandrel);
    return _createClass(Picture, [{
      key: "doLayout",
      value: function doLayout() {
        var _this = this;
        var iconEditor = this.queryWidget('iconEditor');
        if (iconEditor) {
          return iconEditor.dimensions().then(function (dims) {
            var jq = _this.jq(),
              imageWidth = dims ? dims[0] : 1,
              imageHeight = dims ? dims[1] : 1,
              _this$properties$toVa = _this.properties().toValueMap(),
              halign = _this$properties$toVa.halign,
              valign = _this$properties$toVa.valign,
              scale = _this$properties$toVa.scale,
              minScaleFactor = _this$properties$toVa.minScaleFactor,
              maxScaleFactor = _this$properties$toVa.maxScaleFactor;
            var scaledLayout = new ScaledLayout({
              outerWidth: jq.width(),
              outerHeight: jq.height(),
              innerWidth: imageWidth,
              innerHeight: imageHeight,
              halign: halign.getTag(),
              valign: valign.getTag(),
              scale: scale.getTag(),
              minScaleFactor: minScaleFactor,
              maxScaleFactor: maxScaleFactor
            });
            iconEditor.jq().css(scaledLayout.getTransformCss());
          });
        }
      }
    }]);
  }(spandrel(function (model, _ref) {
    var props = _ref.props,
      rootElement = _ref.rootElement;
    var image = props.image,
      halign = props.halign,
      valign = props.valign,
      style = rootElement.style,
      imageOrd = String(image);
    var div = document.createElement('div');
    style.alignItems = toFlexAlign(valign.getTag());
    style.justifyContent = toFlexAlign(halign.getTag());
    var iconEditor = {
      dom: div,
      value: [imageOrd],
      type: IconEditor,
      properties: {
        imageErrorBehavior: "hide",
        draggable: false
      }
    };
    return {
      iconEditor: iconEditor
    };
  }));
  function toFlexAlign(tag) {
    switch (tag) {
      case 'top':
      case 'left':
        return 'flex-start';
      case 'center':
        return 'center';
      case 'bottom':
      case 'right':
      case 'fill':
        return 'flex-end';
    }
  }
});

==> Tridium_EMEA_N4_Supervisor-4.14.3.24.zip: rc/ux/Picture.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
/**
 * Copyright 2020 Tridium, Inc. All Rights Reserved.
 */

/* eslint-env browser */

/**
 * API Status: **Private**
 * @module nmodule/bajaui/rc/ux/Picture
 */
define(['baja!', 'bajaux/spandrel', 'bajaux/icon/iconUtils', 'jquery', 'nmodule/webEditors/rc/fe/baja/IconEditor', 'nmodule/webEditors/rc/fe/fe', 'nmodule/bajaui/rc/util/ScaledLayout', 'baja!bajaui:Halign,bajaui:ScaleMode,bajaui:Valign,gx:Image'], function (baja, spandrel, iconUtils, $, IconEditor, fe, ScaledLayout) {
  'use strict';

  var widgetDefaults = function widgetDefaults() {
    return {
      properties: {
        rootCssClass: 'ux-Picture',
        halign: baja.$('bajaui:Halign', 'center'),
        valign: baja.$('bajaui:Valign', 'center'),
        image: baja.$('gx:Image', 'null'),
        scale: baja.$('bajaui:ScaleMode', 'none')
      }
    };
  };

  /**
   * @class
   * @alias module:nmodule/bajaui/rc/ux/Picture
   * @extends {module:bajaux/Widget}
   */
  return /*#__PURE__*/function (_spandrel) {
    function Picture(params) {
      _classCallCheck(this, Picture);
      return _callSuper(this, Picture, [{
        params: params,
        defaults: widgetDefaults()
      }]);
    }
    _inherits(Picture, _spandrel);
    return _createClass(Picture, [{
      key: "doLayout",
      value: function doLayout() {
        var _this = this;
        var iconEditor = this.queryWidget('iconEditor');
        if (iconEditor) {
          return iconEditor.dimensions().then(function (dims) {
            var jq = _this.jq(),
              imageWidth = dims ? dims[0] : 1,
              imageHeight = dims ? dims[1] : 1,
              _this$properties$toVa = _this.properties().toValueMap(),
              halign = _this$properties$toVa.halign,
              valign = _this$properties$toVa.valign,
              scale = _this$properties$toVa.scale,
              minScaleFactor = _this$properties$toVa.minScaleFactor,
              maxScaleFactor = _this$properties$toVa.maxScaleFactor;
            var scaledLayout = new ScaledLayout({
              outerWidth: jq.width(),
              outerHeight: jq.height(),
              innerWidth: imageWidth,
              innerHeight: imageHeight,
              halign: halign.getTag(),
              valign: valign.getTag(),
              scale: scale.getTag(),
              minScaleFactor: minScaleFactor,
              maxScaleFactor: maxScaleFactor
            });
            iconEditor.jq().css(scaledLayout.getTransformCss());
          });
        }
      }
    }]);
  }(spandrel(function (model, _ref) {
    var props = _ref.props,
      rootElement = _ref.rootElement;
    var image = props.image,
      halign = props.halign,
      valign = props.valign;
    var style = rootElement.style;
    var div = document.createElement('div');
    style.alignItems = toFlexAlign(valign.getTag());
    style.justifyContent = toFlexAlign(halign.getTag());
    var iconEditor = {
      dom: div,
      value: image,
      type: IconEditor,
      properties: {
        imageErrorBehavior: "hide",
        draggable: false
      }
    };
    return {
      iconEditor: iconEditor
    };
  }));
  function toFlexAlign(tag) {
    switch (tag) {
      case 'top':
      case 'left':
        return 'flex-start';
      case 'center':
        return 'center';
      case 'bottom':
      case 'right':
      case 'fill':
        return 'flex-end';
    }
  }
});
